run PLUGIN_RADIUS_ACCOUNT for Start records
authorBrendan O'Dea <bod@optus.net>
Fri, 9 Dec 2005 00:43:17 +0000 (00:43 +0000)
committerBrendan O'Dea <bod@optus.net>
Fri, 9 Dec 2005 00:43:17 +0000 (00:43 +0000)
Changes
l2tpns.h
l2tpns.spec
radius.c

diff --git a/Changes b/Changes
index 1e40548..961aabf 100644 (file)
--- a/Changes
+++ b/Changes
@@ -1,3 +1,6 @@
+* Fri Dec 9 2005 Brendan O'Dea <bod@optus.net> 2.1.14
+- Run PLUGIN_RADIUS_ACCOUNT for Start records.
+
 * Wed Dec 7 2005 Brendan O'Dea <bod@optus.net> 2.1.13
 - Add test/ping-sweep.
 - Apply spec changes from Charlie Brady: use License header, change
index b594ee4..f27939c 100644 (file)
--- a/radius.c
+++ b/radius.c
@@ -1,6 +1,6 @@
 // L2TPNS Radius Stuff
 
-char const *cvs_id_radius = "$Id: radius.c,v 1.45 2005-10-19 03:09:30 bodea Exp $";
+char const *cvs_id_radius = "$Id: radius.c,v 1.46 2005-12-09 00:43:17 bodea Exp $";
 
 #include <time.h>
 #include <stdio.h>
@@ -304,11 +304,11 @@ void radiussend(uint16_t r, uint8_t state)
                                p[1] = 6;
                                *(uint32_t *) (p + 2) = htonl(session[s].cout_wrap);
                                p += p[1];
+                       }
 
-                               {
-                                       struct param_radius_account acct = { &tunnel[session[s].tunnel], &session[s], &p };
-                                       run_plugins(PLUGIN_RADIUS_ACCOUNT, &acct);
-                               }
+                       {
+                               struct param_radius_account acct = { &tunnel[session[s].tunnel], &session[s], &p };
+                               run_plugins(PLUGIN_RADIUS_ACCOUNT, &acct);
                        }
                }
        }
--- a/l2tpns.h
+++ b/l2tpns.h
@@ -1,5 +1,5 @@
 // L2TPNS Global Stuff
-// $Id: l2tpns.h,v 1.105 2005-12-07 05:21:37 bodea Exp $
+// $Id: l2tpns.h,v 1.106 2005-12-09 00:43:17 bodea Exp $
 
 #ifndef __L2TPNS_H__
 #define __L2TPNS_H__
@@ -15,7 +15,7 @@
 #include <sys/types.h>
 #include <libcli.h>
 
-#define VERSION        "2.1.13"
+#define VERSION        "2.1.14"
 
 // Limits
 #define MAXTUNNEL      500             // could be up to 65535
index 6f0cf4a..48548f1 100644 (file)
@@ -1,6 +1,6 @@
 Summary: A high-speed clustered L2TP LNS
 Name: l2tpns
-Version: 2.1.13
+Version: 2.1.14
 Release: 1
 License: GPL
 Group: System Environment/Daemons
@@ -43,5 +43,5 @@ rm -rf %{buildroot}
 %attr(644,root,root) /usr/share/man/man[58]/*
 
 %changelog
-* Wed Dec 7 2005 Brendan O'Dea <bod@optus.net> 2.1.13-1
-- 2.1.13 release, see /usr/share/doc/l2tpns-2.1.13/Changes
+* Fri Dec 9 2005 Brendan O'Dea <bod@optus.net> 2.1.14-1
+- 2.1.14 release, see /usr/share/doc/l2tpns-2.1.14/Changes
index 98941cb..c952d64 100644 (file)